#! /bin/bash
#
# This script installs Loway Uniloader
#

VERSION=24.11.2-7a98ef6

die() {
	echo "Install failed: ${1}"
	exit 1
}


#
# Now installing 
#

for BINARY in echo rm mkdir cp readlink id uname dirname
do
	if [ "$( which "${BINARY}" > /dev/null 2>&1 ; echo "${?}" )" != "0" ]
	then
		die "Missing "${BINARY}""
	fi
done


# Check if the system uses systemd
if ! command -v systemctl &> /dev/null; then
  die "This script requires systemd. Aborting."
fi

# Check the architecture of the CPU
CPU_ARCH=$(uname -m)

case $CPU_ARCH in
  x86_64)
    ULVERSION="uniloader_amd64"
    ;;
  i686)
    ULVERSION="uniloader_386"
    ;;
  armv7l)
    ULVERSION="uniloader_arm7"
    ;;
  aarch64)
    ULVERSION="uniloader_arm64"
    ;;
  *)
    die "Unknown CPU: $CPU_ARCH"
    ;;
esac


# Check if the effective user ID is not 0 (root)
if [ "$(id -u)" -ne 0 ]; then
    die "This script must be run as root or with sudo"
fi

# Get the directory where the script is located
# so relative paths work
script_dir=$(dirname "$0")
cd "$script_dir"


echo "Now installing Uniloader ${VERSION}: ${ULVERSION}"
ULVERSIONPATH=$(readlink -f ./bin/${ULVERSION})

rm -f /usr/bin/uniloader
ln -s ${ULVERSIONPATH} /usr/bin/uniloader

# check whether it's working

uniloader -v
if [ $? -eq 0 ]; then
  echo "-----------"
else
  die "Command 'uniloader' failed with exit status $?"
fi

for INIT in uniloader unitracker audiovault uniloader-freeswitch
do
	echo "Installing service ${INIT}"

	ETCFILE=/etc/${INIT}
	UNITNAME=${INIT}.service

	cp "./init-scripts/systemd/${UNITNAME}" /lib/systemd/system/${UNITNAME}

	if [ ! -e "${ETCFILE}" ]; then
    	cp "./init-scripts/systemd/${INIT}" "${ETCFILE}"
	else
		echo "   Not changing configuration for ${ETCFILE}"
	fi

	systemctl daemon-reload

	# Check if the unit is active
	if systemctl is-active "${UNITNAME}" &> /dev/null; then
	    # Unit is active, restart it
	    systemctl restart "${UNITNAME}"
	    if [ $? -eq 0 ]; then
	        echo "   Unit ${UNITNAME} restarted successfully."
	    else
	        die "Failed to restart unit ${UNITNAME}."
	    fi
	else
	    # Unit is not active, do not restart
	    echo "   Unit ${UNITNAME} is not active, skipping restart."
	fi

done

# Copy an empty splitter file, if it does not exist
SPLITTERFILE=/etc/uniloader_splitter.json
if [ ! -e "${SPLITTERFILE}" ]; then
	cp "./init-scripts/systemd/uniloader_splitter.json" "${SPLITTERFILE}"
else
	echo "Configuration unchanged for ${SPLITTERFILE}"
fi



# Making sure that uniloder is started and restarts on boot
systemctl enable uniloader
systemctl start uniloader

cat << EOF

*Service 'uniloader' installed sucecssfully.*

Please set its credentials in '/etc/uniloader' and use the
supplied script './check.sh upload' to make sure they are valid.
When done, restart with 'systemctl restart uniloader'.

Other services (unitracker, audiovault, uniloader-freeswitch)
were created but not started. 

EOF


# checks
#./check.sh all




